@@ -17,9 +17,10 @@ from .resources import (
     UpdateResource,
     UserResource,
     WorkspaceResource,
+    WebhooksResource,
+    AccountResource,
+    BaseResource
 )
-from .resources.base import BaseResource
-from .resources.webhooks import WebhooksResource
 
 
 class MondayClient:
@@ -38,6 +39,7 @@ class MondayClient:
         self.notifications = NotificationResource(token=token)
         self.base = BaseResource(api_key=token)
         self.webhooks = WebhooksResource(token=token)
+        self.account = AccountResource
 
     def __str__(self):
         return f'MondayClient {__version__}'
