@@ -4,6 +4,7 @@ from monday.query_joins import (
     get_boards_by_id_query,
     get_boards_query,
     get_columns_by_board_query,
+    get_board_activity_query,
 )
 from monday.resources.base import BaseResource
 
@@ -31,3 +32,7 @@ class BoardResource(BaseResource):
     def create_board(self, board_name, board_kind, workspace_id):
         query = create_board_by_workspace_query(board_name, board_kind, workspace_id)
         return self.client.execute(query)
+
+    def get_board_activity(self, board_id, from_date, to_date, page, limit):
+        query = get_board_activity_query(board_id, from_date, to_date, page, limit)
+        return self.client.execute(query)
